@@ -45,6 +45,7 @@ from logilab.common.fileutils import norm_open
 from logilab.common.ureports import Table, Text, Section
 from logilab.common.graph import ordered_nodes
 from logilab.common.__pkginfo__ import version as common_version
+from logilab.common.compat import set
 
 from logilab.astng import MANAGER, nodes
 from logilab.astng.__pkginfo__ import version as astng_version
@@ -208,9 +209,11 @@ This is used by the global evaluation report (R0004).'}),
                 {'type' : 'csv', 'metavar': '<msg ids>',
                  'short': 'd',
                  'group': 'Messages control',
-                 'help' : 'Disable the message, report, category or checker with the '
-                 'given id(s). You can either give multiple identifier '
-                 'separated by comma (,) or put this option multiple time.'}),
+                 'help' : 'Disable the message, report, category or checker '
+                 'with the given id(s). You can either give multiple identifier'
+                 ' separated by comma (,) or put this option multiple time '
+                 '(only on the command line, not in the configuration file '
+                 'where it should appear only once).'}),
                )
 
     option_groups = (
